@@ -23,6 +23,12 @@ if (!isGeneric("coordnames<-"))
 if (!isGeneric("dimensions"))
 	setGeneric("dimensions", function(obj)
 		standardGeneric("dimensions"))
+#if (!isGeneric("fullgrid"))
+#	setGeneric("fullgrid", function(obj)
+#		standardGeneric("fullgrid"))
+#if (!isGeneric("fullgrid<-"))
+#	setGeneric("fullgrid<-", function(obj, value)
+#		standardGeneric("fullgrid<-"))
 if (!isGeneric("geometry"))
 	setGeneric("geometry", function(obj)
 		standardGeneric("geometry"))
@@ -50,9 +56,9 @@ if (!isGeneric("polygons<-"))
 if (!isGeneric("proj4string"))
 	setGeneric("proj4string", function(obj)
 		standardGeneric("proj4string"))
-#if (!isGeneric("proj4string<-"))
-#	setGeneric("proj4string<-", function(obj, value)
-#		standardGeneric("proj4string<-"))
+if (!isGeneric("proj4string<-"))
+	setGeneric("proj4string<-", function(obj, value)
+		standardGeneric("proj4string<-"))
 if (!isGeneric("spplot"))
 	setGeneric("spplot", function(obj, ...)
 		standardGeneric("spplot"))
