@@ -33,23 +33,25 @@ gridlines = function(x, easts = pretty(bbox(x)[1,]),
 }
 
 gridat <- function(x, easts = pretty(bbox(x)[1,]), 
-	norths = pretty(bbox(x)[2,]), offset=0.5)
+	norths = pretty(bbox(x)[2,]), offset=0.5, side="WS")
 {
 	isp = is.projected(x)
 	if (is.na(isp) || isp) stop("x must not be projected")
 	bb = bbox(x)
+        ac <- ifelse (side == "WS", 1L, 2L)
 	easts <- easts[easts > bb[1,1] & easts < bb[1,2]]
 	norths <- norths[norths > bb[2,1] & norths < bb[2,2]]
-	a1 <- cbind(easts, rep(bb[2,1], length(easts)))
+	a1 <- cbind(easts, rep(bb[2,ac], length(easts)))
 	a1lab <- degreeLabelsEW(a1[,1])
-	a2 <- cbind(rep(bb[1,1], length(norths)), norths)
+	a2 <- cbind(rep(bb[1,ac], length(norths)), norths)
 	a2lab <- degreeLabelsNS(a2[,2])
 	as <- SpatialPoints(rbind(a1, a2), CRS(proj4string(x)))
 	res <- SpatialPointsDataFrame(as, 
 		data.frame(
 		#AttributeList(list(
 		labels = c(a1lab, a2lab), 
-			pos = c(rep(1, length(easts)), rep(2, length(norths))), 
+			pos = c(rep(1L+((ac-1)*2), length(easts)),
+                        rep(2L+((ac-1)*2), length(norths))), 
 			offset = rep(offset, length(easts)+length(norths))
 		)
 		#)
